package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````J!@``#0```"HD0````0`!30`(``)
M`"@`&P`:``$``'#(B0``R(D``,B)```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#4B0``U(D```4```````$`
M`0```*2-``"DC0$`I(T!`)P"``"P$@``!@```````0`"````K(T``*R-`0"L
MC0$`&`$``!@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DI(T`
M`*2-`0"DC0$`7`(``%P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`S#'KJF1?33X0>?FFQCG#7??A?Q@$
M````$`````$```!'3E4```````,````"`````````#T```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PXH!)%B@``"```````````3```
M``````!-````3@```%``````````40````````!2````4P```%0```!5````
M`````%8```!8`````````````````````````````````````````%D```!:
M````7````%X```````````````````!?`````````&``````````80```&(`
M````````8P```&0`````````90```&8`````````````````````````````
M`&<``````````````&@`````````:0``````````````:@``````````````
M``````````"[XY)\:QJ>4"[%F[9#^M>'%8PES&>OS&9OQ=\?B0=PTZ/@^TG[
MH6Q@`*\TZ+_:5QO59-1\P^4_+'ZIG)NM2^/`XD?&`<_>1RT-%.*>(?_D#N&G
M`@K;S>.>6>^7>7=4/)2S`8MO#3J7"]EQ6!PS8MOM:PE#UD-%U>QK?YI\````
M``````````````````````#\$@````````,`"P```````)`!```````#`!8`
M0`(`````````````$@```.$"`````````````!(```"U`@`````````````B
M````^@(`````````````$0```*(#`````````````!(````!````````````
M```@````I@$`````````````$@```)0"`````````````!(```#2`@``````
M```````2````,0$`````````````$@```!8#`````````````!$```!;`@``
M```````````2````EP``````````````$@```$<"`````````````!(```#8
M```````````````2````+`$`````````````$@```&("`````````````!(`
M```D`@`````````````2````Z@$`````````````$@````0#````````````
M`!(```#[`0`````````````2````"`(`````````````$@```(H!````````
M`````!$```#G```````````````2````1@``````````````$0```+L`````
M`````````!(```";`@`````````````2````C0(`````````````$0````P!
M`````````````!(```"R`0`````````````2````-@$`````````````$@``
M`'L"`````````````!(```"K`0`````````````2````0@$`````````````
M$@```.@"`````````````!(```!3```````````````2````'0``````````
M````(````!T"`````````````!(```#4`0`````````````2````,@(`````
M````````$@```$D!`````````````!(```"D`@`````````````2````@```
M````````````$@```)4!`````````````!(```#$`@`````````````2````
M%P$`````````````$@```(P``````````````!(````"`@`````````````2
M````.0(`````````````$@```&D!`````````````!(```!\`0``````````
M```2````8P``````````````$@```+```````````````!(```!-`@``````
M```````2````6`$`````````````$@```!8"`````````````!(```#:`@``
M```````````2````]0``````````````$@```"L"`````````````!(```!O
M```````````````2````^P(`````````````(0```*L"`````````````!(`
M``#)```````````````2````IP``````````````$@```"P`````````````
M`"````#\`@`````````````1````@P(`````````````$@```-D!````````
M`````!(````0`@`````````````2````S@$`````````````$@```'`"````
M`````````!(```#A`0`````````````2````N@$`````````````$@```$<$
M``!4H`$``````!``%P!A!```1$@``$`!```2``T`<0,``'`C```$````$@`-
M`/`#```X1P``#`$``!(`#0"L!```W$8``%P````2``T`UP,``$@F```H````
M$@`-`*L#``!0.0``D`$``!(`#0`]!```/)`!``0````1`!8`5`0``'`F``"8
M!0``$@`-`(P$``#8+```7`$``!(`#0"_`P``5*`!```````0`!<`O@,``%2@
M`0``````$``7`+4$``"4-@``O`(``!(`#0!W!```+"(``%`````2``T`D`,`
M`,`L```8````$@`-``@$```(2@``!````!$`#P#*`P``("8``"@````2``T`
MXP,``#0N``!@"```$@`-`&$#``#H20``!````!(`#0!_!```=",``*P"```2
M``T`%P0``'PB``#T````$@`-`"T$``"$20``9````!(`#0!,!```5*`!````
M```0`!<`@@,``$"0`0``````$``7`)X$```(+```N````!(`#0#]`P```)`!
M```````@`!8`:P0``$"0`0``````$``7``$$``"H&````````!(`#0#[`P``
M`)`!```````0`!8`MP,``$"0`0``````$``6`/4"``#X%0``L`(``!(`#0``
M7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])
M5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4$Q?9&]?=6YD=6UP`%!E<FQ?9W9?
M9F5T8VAP=@!097)L7VUG7W-E=`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?9V5T
M7W-V`%!E<FQ?;F5W6%,`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<G5N`'!E<FQ?
M<&%R<V4`4&5R;%]S=E]S971P=@!097)L7W-V7W-E='!V;@!P97)L7V-O;G-T
M<G5C=`!P97)L7V1E<W1R=6-T`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R
M;%]A;&QO8P!097)L7V-R;V%K7VYO8V]N=&5X=`!P97)L7V9R964`4&5R;%]S
M869E<WES;6%L;&]C`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%-?9FQA9W,`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`4$Q?=&AR7VME>0!?
M7V5R<FYO7VQO8V%T:6]N`')E860`;W!E;C8T`&QS965K-C0`<'1H<F5A9%]G
M971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`
M9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD
M:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A
M=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`
M<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK
M`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N
M=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB
M<&5R;"YS;P!L:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD+6QI;G5X+6%R
M;6AF+G-O+C,`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`7U]B
M<W-?<W1A<G1?7P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE
M86YU<`!?961A=&$`7U]B<W-?96YD7U\`<&%R7V)A<V5N86UE`'!A<E]D:7)N
M86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?
M<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I
M;FET`&UY7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F
M:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T
M=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H85]I;FET`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!'3$E"0U\R+C0`+W5S<B]L:6(O<&5R;#4O-2XS-"]C;W)E
M7W!E<FPO0T]210`````````"``(``@`"``(````#``(``@`"``0``@````(`
M``````(``@`"``(``@`"`````````````@`"`````P````(``P`"``(`````
M``(``@`"`````@````,``@```````@`"`````````````@````(``@````(`
M```"``(``````````@`"``(``@`#``(``@`#``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M```!``$`30,``!`````@````%&EI#0``!`#+!`````````$``0`S`P``$```
M`"`````4:6D-```#`,L$`````````0`!`$,#```0`````````!1I:0T```(`
MRP0```````"DC0$`%P```*B-`0`7````Q(\!`!<```#HCP$`%P```/"/`0`7
M````!)`!`!<````,D`$`%P```!"0`0`7````&)`!`!<````<D`$`%P```""0
M`0`7````))`!`!<````HD`$`%P```#"0`0`7````-)`!`!<````\D`$`%P``
M`,B/`0`5!0``S(\!`!4(``#0CP$`%0T``-2/`0`5#P``V(\!`!49``#<CP$`
M%1L``."/`0`5'@``Y(\!`!4G``#LCP$`%30``/2/`0`5/@``^(\!`!5#``#\
MCP$`%40``-".`0`6`P``U(X!`!8$``#8C@$`%@4``-R.`0`6!P``X(X!`!8)
M``#DC@$`%@H``.B.`0`6"P``[(X!`!8,``#PC@$`%@X``/2.`0`6$```^(X!
M`!81``#\C@$`%A(```"/`0`6$P``!(\!`!84```(CP$`%A4```R/`0`6%@``
M$(\!`!87```4CP$`%A@``!B/`0`6&@``'(\!`!8<```@CP$`%AT``"2/`0`6
M'P``*(\!`!8@```LCP$`%B$``#"/`0`6(@``-(\!`!8C```XCP$`%B0``#R/
M`0`6)0``0(\!`!8F``!$CP$`%B<``$B/`0`6*```3(\!`!8I``!0CP$`%BH`
M`%2/`0`6*P``6(\!`!8L``!<CP$`%BT``&"/`0`6+@``9(\!`!8O``!HCP$`
M%C```&R/`0`6,0``<(\!`!8R``!TCP$`%C,``'B/`0`6-0``?(\!`!8V``"`
MCP$`%C<``(2/`0`6.```B(\!`!8Y``",CP$`%CH``)"/`0`6.P``E(\!`!8\
M``"8CP$`%CT``)R/`0`60```H(\!`!9!``"DCP$`%D(``*B/`0`610``K(\!
M`!9&``"PCP$`%D<``+2/`0`62```N(\!`!9)``"\CP$`%DH``,"/`0`62P``
M"$`MZ7X!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y:Q[`0``QH_B%\J,XJS[O.4`
MQH_B%\J,XJ3[O.4`QH_B%\J,XIS[O.4`QH_B%\J,XI3[O.4`QH_B%\J,XHS[
MO.4`QH_B%\J,XH3[O.4`QH_B%\J,XGS[O.4`QH_B%\J,XG3[O.4`QH_B%\J,
MXFS[O.4`QH_B%\J,XF3[O.4`QH_B%\J,XES[O.4`QH_B%\J,XE3[O.4`QH_B
M%\J,XDS[O.4`QH_B%\J,XD3[O.4`QH_B%\J,XCS[O.4`QH_B%\J,XC3[O.4`
MQH_B%\J,XBS[O.4`QH_B%\J,XB3[O.4`QH_B%\J,XAS[O.4`QH_B%\J,XA3[
MO.4`QH_B%\J,X@S[O.4`QH_B%\J,X@3[O.4`QH_B%\J,XOSZO.4`QH_B%\J,
MXO3ZO.4`QH_B%\J,XNSZO.4`QH_B%\J,XN3ZO.4`QH_B%\J,XMSZO.4`QH_B
M%\J,XM3ZO.4`QH_B%\J,XLSZO.4`QH_B%\J,XL3ZO.4`QH_B%\J,XKSZO.4`
MQH_B%\J,XK3ZO.4`QH_B%\J,XJSZO.4`QH_B%\J,XJ3ZO.4`QH_B%\J,XISZ
MO.4`QH_B%\J,XI3ZO.4`QH_B%\J,XHSZO.4`QH_B%\J,XH3ZO.4`QH_B%\J,
MXGSZO.4`QH_B%\J,XG3ZO.4`QH_B%\J,XFSZO.4`QH_B%\J,XF3ZO.4`QH_B
M%\J,XESZO.4`QH_B%\J,XE3ZO.4`QH_B%\J,XDSZO.4`QH_B%\J,XD3ZO.4`
MQH_B%\J,XCSZO.4`QH_B%\J,XC3ZO.4`QH_B%\J,XBSZO.4`QH_B%\J,XB3Z
MO.4`QH_B%\J,XASZO.4`QH_B%\J,XA3ZO.4`QH_B%\J,X@SZO.4`QH_B%\J,
MX@3ZO.4`QH_B%\J,XOSYO.4`QH_B%\J,XO3YO.4`QH_B%\J,XNSYO.4`QH_B
M%\J,XN3YO.4`QH_B%\J,XMSYO.4`QH_B%\J,XM3YO.4`QH_B%\J,XLSYO.5P
M0"WI6,*?Y2#03>)4,I_E#,"/X%!"G^44`(WE%`"-XA`0C>40$(WB#""-Y0P@
MC>($0(_@`S"<YP`PD^4<,(WE`#"@XYG__^L@(I_E(#*?Y0(@E.<#`)3G`A"@
MX>0,`.L0,I_E`S"4YP!0T^4``%7C5P``"@`RG^4#0)3G``"4Y=O__^L`,*#A
M``"4Y9XCT^4"((+CGB/#Y=7__^L44)WEGC/0Y00@A>(#4(7B`3"#XP<!<N.>
M,\#E8P``B@(!H.%<___KM"&?Y;0QG^4"((_@$$"=Y0,PC^``()+E`!"4Y0@@
M@.6<(9_E!`"#Y0(@C^`4,)WE#""`Y8PAG^4!`%/C`!"`Y0(@C^`$((#E3P``
MV@,QH.$$$(3B#,"`X@-`A.`$X)'D!."LY00`4>'[__\:##"#XE1AG^4`$*#C
M`!"-Y04@H.$&8(_@`Q"`YT`1G^4`,*#A`1"/X`P`EN5T___K`$!0XB<```HH
M49_E&&"-X@50C^`,`)7E'___ZQ@!G^4&$*#A``"/X*<``.L``%#C(```"@0Q
MG^4#,(_@#`"3Y0#__^M<___K]""?Y;0PG^4"((_@`S"2YP`@D^4<,)WE`B`S
MX",``!H$`*#A(-"-XG"`O>@1___KR""?Y0``4.,"((_@#`""Y1L```KJ_O_K
MA#"?Y0-`E.<``)3E?/__ZT=7P.6<___J#`"6Y6/__^L`0*#AT___Z@@`E>4`
M`%#C`0``"DL(`.O9___J>`"?Y080H.$``(_@>P``ZP``4.,(`(7ETO__"O7_
M_^I'___K$#"@X[;__^K;_O_K`0"@XPS__^NT>`$`#`$``)1X`0`H`0``,`$`
M`!@!```4`0``<'D!`'!Y`0!0-@``-#8```!Y`0!`"@``U'@!`(`S``"L>`$`
M%'<!`&1X`0!P,@```+"@XP#@H.,$$)WD#2"@X00@+>4$`"WE**"?Y20PC^(#
MH(K@(,"?Y0S`FN<$P"WE&#"?Y0,PFN<4`)_E``":Y]S^_^LR___KU'4!```!
M```D`0``+`$``!0PG^44()_E`S"/X`(@D^<``%+C'O\O`=;^_^JT=0$`(`$`
M`"P`G^4L,)_E``"/X"@@G^4#,(_@``!3X0(@C^`>_R\!&#"?Y0,PDN<``%/C
M'O\O`1/_+^$,=P$`!'<!`(!U`0`(`0``.`"?Y3@0G^4``(_@-""?Y0$0C^``
M$$'@`B"/X*$_H.%!$8/@P1"PX1[_+P$8,)_E`S"2YP``4^,>_R\!$_\OX<AV
M`0#`=@$`/'4!`#0!``!,,)_E3""?Y0,PC^`"((_@`##3Y0``4^,>_R\1.#"?
MY1!`+>D#,)+G``!3XP(```HH,)_E`P"?YT_^_^O*___K'#"?Y0$@H.,#,(_@
M`"##Y1"`O>AX=@$`^'0!``0!```0=@$`.'8!`-#__^K,,)_E\$<MZ0"04.(#
M,(_@*P``"KP@G^4",)/G`("3Y0``6.,H```*`%#9Y0%PH.$``%7C/0!5$P%0
MH!,`4*`#$0``&@!`F.4``%3C#```"@A@H.$$`*#A!2"@X0D0H.')_O_K``!0
MXP(``!H%,-3G/0!3XPL```H$0+;E``!4X_/__QH$`*#A\(>]Z`E0H.$!,/7E
M``!3XST`4Q/[__\:"5!%X.;__^H(8$;@`5"%X@5`A.!&8:#A!`"@X0!@A^7P
MA[WH"4"@X>W__^H(0*#AZ___ZHQT`0`X`0``9"&?Y60QG^4"((_@\$$MZ0!0
M4.)XT$WB`S"2YP`PD^5T,(WE`#"@XP(```H`,-7E``!3XPD``!HT(9_E+#&?
MY0(@C^`#,)+G`""3Y70PG>4"(#/@0P``&GC0C>+P@;WH-?[_ZP!`4.+R__\*
M!'&?Y0=PC^`$`*#A@/[_ZP``4.,J```*$S#0Y1-@@.(N`%/C`@``&@$PUN4`
M`%/C]/__"A,PT.4N`%/C)0``"@4`H.$Y_O_K`("@X08`H.$V_O_K``"(X`(`
M@.(A_O_K!S"@X0$0H.,$8(WE`"#@XP!@H.$`4(WE._[_ZP@@C>(&$*#A`P"@
MXVK^_^L!`'#C!@"@X0,```H8,)WE#SH#X@$)4^,2```*\/W_ZP8`H.'3_?_K
M!`"@X57^_^L``%#CU/__&@0`H.%I_O_K!0"@X=']_^N\___J`3#6Y2X`4^/6
M__\:`C#6Y0``4^/%__\*TO__ZJ;__^OK___JU?W_Z[1S`0`,`0``?',!`,PN
M``"4P)_EE#"?Y0S`C^`00"WI`$"@X7#03>(#`*#C`S"<YPT@H.$$$*#A`#"3
MY6PPC>4`,*#C1_[_ZP``4.,``*`3!```&A`PG>4/.@/B"@I3XP$)4Q,)```*
M1""?Y3PPG^4"((_@`S"2YP`@D^5L,)WE`B`SX`<``!IPT(WB$("]Z`(0H.,$
M`*#A%/[_ZQ`/;^&@`J#A[___ZJK]_^LX<@$`#`$``.!Q`0`00"WI`$"@X=K]
M_^L!,$#B`S"$X`,`5.$#(*`Q`P``.B8``.H",*#A!`!2X2,```H",*#A`1!2
MY"\`4>/X__\*`P!4X1T``"H!,$/B`P!4X1P```H`(-/E+P!2X_G__QH!,$/B
M`P``Z@`0TN4!,$/B+P!1XP(``!H#(*#A`P!4X?C__SH$($+@`C""X@$*4^,(
M``"*6`"?Y000H.$!.J#C`2""X@``C^``0*#A=?W_ZP0`H.$0@+WH``"@XQ"`
MO>@#`%3AY?__&@`PU.4O`%/C`P``"AP`G^400+WH``"/X&O]_^H0`)_E$$"]
MZ```C^!G_?_JA'(!`$0L``#\*P``\$,MZ0!`H.$0`9_E`6"@X0P1G^4``(_@
M`=I-X@S03>(`@9_E`3J-X@1PC>(!$)#G_R\`X_``G^4$,(/B`!"1Y0`0@^4`
M$*#C!Q"@X0``C^`(@(_@8_W_ZP#`4.(E``#:R#"?Y0A0C>(#,)CG`8!,X@A0
MA>``D)/E!#!5Y0``4^,:```:``!8XQT```H((*#A+Q"@XP<`H.&C_?_K``!0
MXQ<```H)`*#AQOW_ZP@PH.$'(*#A!!"@X:K]_^MP$)_E`3J-XE@@G^4$,(/B
M`1"/X`(@D><`$)+E`""3Y0$0,N`-```:`=J-X@S0C>+P@[WH#("@X>3__^HP
M,)_E`S"8YP"0D^4)`*#AKOW_ZP8@H.$$$*#A,/W_Z^?__^H?_?_KA'`!``P!
M``!(<`$`V"L``!0!``#,;P$`&"*?Y1@RG^4"((_@\$<MZ0%`H.$(T$WB`%"@
MX0,PDN<`@I_E`#"3Y00PC>4`,*#C`##1Y0B`C^`]`%/C`4"!`@0`H.$]_?_K
M#1"@X0!@H.$%`*#AF_[_ZP"04.)````*-OW_ZP``5N$W``":N#&?Y0!PG>4#
M@)CG!W&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4PH.$!(//E``!2XST`
M4A/[__\:!3!#X`(`AN(`8)CE`P"`X`[]_^L``%#C!P"&YQ8```H`,)CE!0"@
MX0`@G>4"$9/G`3#0Y``PP>4``%/C/0!3$P8```H!(('B`3#0Y`(0H.$!,,+D
M/0!3XP``4Q/Y__\:`2"@X3TPH.,`,,'E`3#4Y`$PXN4``%/C^___&@0AG^7T
M,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^`U```:"-"-XO"'O>@!D$GB`3#4Y`$P
MZ>4``%/C^___&N___^K`,)_E`X"8YP!PF.4`,)?E``!3XR0```H',*#A!""S
MY0D0H.$!D(GB``!2X_K__QH#$('B`1&@X9`PG^4#,(_@`""3Y0``4N,/```:
M`0"@X0$@H.,`((/ES?S_ZP"@4.+6__\*!Q"@X0EQH.$'(*#AB_S_ZP"@B.4!
M,(GB`""@XP,ABN<`D(WEHO__Z@<`H.&D_/_K`*"@X0``4.,``(CEQO__"@EQ
MH.'R___J`Y"@X0@0H./?___JD?S_ZUAO`0`,`0``+&\!`#@!```T;@$`0&\!
M`#!`+>EL0)_E;#"?Y0S03>($0(_@`U"4YP``E>4-_?_K``"5Y0O]_^M0()_E
M4#"?Y5`0G^4#,(_@`B"4YP$0C^#%_/_K``"5Y0+]_^LX,)_E.""?Y0#`H.,T
M$)_E`S"/X`(@C^`($(WH`1"/X,_\_^L,T(WB,("]Z!AM`0`4`0``$`$``,AG
M``"(*```/"L``)@4``!X*```$$`MZ3!`G^4P,)_E!$"/X`,PE.<``)/EZ/S_
MZR`@G^4@,)_E(!"?Y0,PC^`"()3G`1"/X!!`O>BA_/_JA&P!`!0!```0`0``
M/&<``/PG``#8$)_E,$`MZ=0@G^4!$(_@`MI-XB303>(".HWB%$"-X@(@D><<
M,(/B`""2Y0`@@^4`(*#C<_S_ZZ@0G^4!(`'CI#"?Y0$0C^#P`,WA`S"/X`$0
MH.,$`*#A?_S_ZP$:C>(8$('B!`"@X0$JH.,,$(WE1OS_ZP!`4.(`4*"S"```
MN@$`A.)3_/_K`%!0X@0```H,$)WE!""@X1C\_^L`,*#C!##%YT00G^4".HWB
M,""?Y1PP@^(!$(_@`B"1YP`0DN4`()/E`1`RX`,``!H%`*#A`MJ-XB30C>(P
M@+WH&?S_ZS1L`0`,`0``V"<``,0G``",:P$`P?__ZG#"G^7P3RWI`&"@X6@B
MG^4,P(_@0MU-X@S03>)<`I_E0CV-XAAPC>("()SG`5"@X0``C^`'$*#A!#"#
MX@`@DN4`((/E`""@XYC]_^LO$*#C`$"@X08`H.$X_/_K``!0XQ$```H8`I_E
M!A"@X0``C^#<_O_K!@"@X0@2G^5"/8WB]"&?Y00P@^(!$(_@`B"1YP`0DN4`
M()/E`1`RX'0``!I"W8WB#-"-XO"/O>@&`*#A'/S_ZP"`H.$%`*#AX/O_Z\01
MG^4!$(_@3/S_ZP"@4.+C__\*M#&?Y0JPH.&PD9_E`S"/X!0PC>6H,9_E"9"/
MX`,PC^`0,(WE`##;Y0``4^,[```*``!4XP0```H+$*#A!`"@X:;[_^L``%#C
M/P``"@L`H.'_^__K`<!`X@#@H.$,,(O@#"#;YR\`4N,*```:`@!`X@,@H.$`
M`(O@`\!,X`-00.``H*#C#."#X`6@P^8!$'+E+P!1X_K__PH!,(CB#N"#X`$*
M7N.Y__^J&"&?Y810C>(),*#A`1"@XP(@C^`%`*#A1`"-Z0$JH.,`L(WE[_O_
MZP<@H.$%$*#A`P"@XQ[\_^L``%#C`P``&B@PG>4/.@/B`@E3XQH```K,$)_E
M``"@XP$0C^`(_/_K`+"@X0``6^.>__\*`##;Y0``4^/#__\:``!4XQH```H`
M,-3E+@!3XP(```H4L)WE`>"@X]7__^H!,-3E``!3X_G__QI\$)_E``"@XP$0
MC^#S^__K`+"@X>G__^H!$*#C!0"@X>C[_^L``%#CW___&E0`G^4%$*#A``"/
MX&+^_^L%`*#A=_O_ZX/__^H0L)WE`>"@X[W__^IU^__K.&L!``P!``#X)@``
MR"8``,!J`0"`)@``N"4``%PF``"H)0``1"4``'`E```<)0``X"0````PT.4`
M`%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C^O__&A[_+^$`,%#B`P``"@`P
MT^4``%/C````"K#]_^H$`)_E``"/X%+[_^JH(P``'"6?Y1S%G^4<-9_E`B"/
MX'!`+>D,P(_@#,",XC#03>((99_E`S"2YPC@C>(&8(_@!$"-X@`PD^4L,(WE
M`#"@X^Q4G^4/`+SH#P"NZ`50C^`/`+SH#P"NZ``PG.6P,,[A!!"@X08`H.'1
M_/_K``!0XPX```J\-)_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'_
M_PH$,(/B!""3Y00@@^0``%+C^___&NO__^J$9)_E!F"/X`00H.$&`*#AN_S_
MZP``4.,.```*9#2?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*
M!#"#X@0@D^4$((/D``!2X_O__QKK___J,&2?Y09@C^`$$*#A!@"@X:7\_^L`
M`%#C#@``"@PTG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P
M@^($()/E!""#Y```4N/[__\:Z___ZMQCG^4&8(_@!!"@X08`H.&/_/_K``!0
MXPX```JT,Y_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B
M!""3Y00@@^0``%+C^___&NO__^J(8Y_E!F"/X`00H.$&`*#A>?S_ZP``4.,.
M```*7#.?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@
MD^4$((/D``!2X_O__QKK___J-&.?Y09@C^`$$*#A!@"@X6/\_^L``%#C#@``
M"@0SG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E
M!""#Y```4N/[__\:Z___ZN!BG^4&8(_@!!"@X08`H.%-_/_K``!0XPX```JL
M,I_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@
M@^0``%+C^___&NO__^J,8I_E!F"/X`00H.$&`*#A-_S_ZP``4.,.```*5#*?
MY00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D
M``!2X_O__QKK___J.&*?Y09@C^`$$*#A!@"@X2'\_^L``%#C#@``"OPQG^4$
M`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```
M4N/[__\:Z___ZN1AG^4&8(_@!!"@X08`H.$+_/_K``!0XPX```JD,9_E!`"=
MY0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C
M^___&NO__^J089_E!F"/X`00H.$&`*#A]?O_ZP``4.,.```*3#&?Y00`G>4#
M,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O_
M_QKK___J/`&?Y000H.$``(_@X/O_ZP`04.("```**`&?Y0``C^`I_?_K(`&?
MY000H.$``(_@U_O_ZP`04.("```*#`&?Y0``C^`@_?_K!`&?Y000H.$``(_@
MSOO_ZP`04.(1```*\`"?Y0``C^`7_?_KZ!"?Y>@`G^4!$(_@``"/X!+]_^O<
M()_E@#"?Y0(@C^`#,)+G`""3Y2PPG>4"(#/@%P``&C#0C>)P@+WHN`"?Y000
MH.$``(_@MOO_ZP`04.(#```*I`"?Y0``C^#__/_KYO__ZI@0G^4*(*#C&0"-
MX@$0C^".^O_K``!0X]___QJ``)_E(Q"-X@``C^#S_/_KVO__Z@OZ_^M`:`$`
M#&,```P!```H)````&@!`#@!``"L(P``7",``!`C``#`(@``>"(``,`A``#4
M(0``B"$``#PA``!L(```E"```&@@``"$(```0!\``'0@``"H'P``@"```.0?
M``"D8P$`)"```+0?```,(```A!\``)@PG^68$)_EF""?Y0,PC^`!$(_@!.`M
MY0``D^4,T$WB`B"1YP$`<.,`()+E!""-Y0`@H.,)```*;""?Y60PG^4"((_@
M`S"2YP`@D^4$,)WE`B`SX!```!H,T(WB!/"=Y$@`G^4-$*#A``"/X&K[_^L`
M`%#C!```"@``T.4P`%#C``!0$P$`H!,``*`#(#"?Y0,PC^```(/EYO__ZL;Y
M_^OL8P$`I&(!``P!``!T8@$`F!X``&AC`0`00"WIH_G_ZYSY_^L``%#C``"0
M%1"`O>@P(9_E,#&?Y0(@C^#P0"WI*&&?Y1S03>(`4*#A`S"2YP9@C^`0$(WB
M!@"@X0`PD^44,(WE`#"@XT/[_^L`0%#B`@``"@`PU.4``%/C#0``&NP@G^7@
M,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^`P```:T`"?Y040H.$``(_@'-"-XO!`
MO>A^_/_J!1"@X6SY_^L``%#C"0``"JP@G^68,)_E`B"/X`,PDN<`()/E%#"=
MY0(@,^`>```:'-"-XO"`O>@%`*#AOOG_ZP!PH.$$`*#AN_G_ZP``A^`"`(#B
MIOG_ZV@PG^5H()_E`1"@XP,PC^`(0(WE`B"/X`!0C>4$((WE`"#@XP!`H.&\
M^?_K1""?Y20PG^4"((_@`S"2YP`@D^44,)WE`B`SX`00H`$&`*`!T?__"FSY
M_^O<80$`#`$``)`>``",80$`.!X``$1A`0#X'```[!P``-!@`0#P3RWIP!>?
MY8'<3>*\-Y_E!-!-XKBGG^4#,(_@`7R-X@(IC>)T@$?B'`"-Y1#@@^*@!Y_E
M_"""XBA0@^)<P$?B``"/X&A`1^+@8$?B"J"/X`$0D.<`$)'E`!""Y0`0H.,'
M`)/I!P"(Z`\`ON@/`*SH`P">Z`,`C.@'`)7H!P"$Z%0'G^4&$*#A``"/X-?Z
M_^L`0%#B`@``"@`PU.4``%/C'0$`&A[Y_^L7^?_K`(!0XO0```H`4)CE``!5
MX_````H%`*#A9_G_ZX``H.$!`(#B4OG_ZP`@U>4`@*#A``!2XPP```KTMI_E
M"$"@X0NPC^`$`*#A`""-Y0LPH.$`(.#C`1"@XP)`A.)E^?_K`2#UY0``4N/U
M__\:Q`:?Y5A01^(``(_@`@``Z@0`E>0``%#C#0``"@80H.&L^O_K`$!0XOC_
M_PH`,-3E``!3X_7__PH\^__K``!0X_+__PH$`*#A!_G_ZP!04.(3```:`)"@
MXW2P1^()(8?@=$`2Y0``5.,,```*`5")X@51B^``(-3E``!2XP<```H$`*#A
M`9")XBC[_^L``%#C0P``&@1`E>0``%3C]/__&@!0H.,%`*#A*/G_ZP!`H.$(
M`*#A)?G_ZP``A.`!2X#B!$"$X@0`H.$.^?_K_#6?Y0$0H.,,@(WE`S"/X`@P
MC>7L-9_E`("@X0`@X.,`4(WE`S"/X`0PC>78-9_E`S"/X"'Y_^L'':#C"`"@
MX2?Y_^L!`'#C`P``&ACY_^L`$)#E$0!1XZD``!H&(*#A"!"@X0,`H.-3^?_K
M`%!0XAT```J4%9_E'#"=Y9`EG^4!`)KG`*"@XP`PD^4"((_@`("-Y0$0H.,`
M`)#E'_G_ZW`5G^4".8WB."6?Y?PP@^(!$(_@`B"1YP`0DN4`()/E`1`RX$8!
M`!H*`*#A@=R-X@30C>+PC[WH!`"@X:_X_^L`4%#BJ?__"KK__^K0,!?E#SH#
MX@$)4^/=__\:R+`7Y8[X_^L``%OAV?__&M`P%^53,.CG!PU3X]7__QH$`*#A
MQ?C_ZP"@H.'L!)_E!A"@X0``C^`T^O_K`!!0XI0```H<,)WE``"3Y8/\_^L`
ML%#BCP``"@L`H.')^/_K`$"@X0,`4.,,``":L!2?Y00`0.(``(O@`1"/X&3X
M_^L``%#C!0``&@0`5./A```*!$"+X`4P5.4O`%/CW0``"H!$G^4$0(_@`#"4
MY0$`<^-[```*``!3XXD```IH%)_E:`2?Y0$0C^!DE)_E``"/X&!TG^5;^__K
M7&2?Y:/X_^M8-)_E"`"-Y0$0H.,#,(_@##"-Y4@TG^4*`*#A`("-Y0`@X.,#
M,(_@!#"-Y30TG^4)D(_@!W"/X`9@C^`#,(_@I_C_ZP\``.JB^/_K`#"0Y1$`
M4^,1```:C/C_ZP%0A>(`P*#A"3"@X00@H.$!$*#C"@"@X1!PC>4,4(WE0!"-
MZ0"`C>66^/_K!QV@XPH`H.&<^/_K`$"@X0$`<./I__\*"`"@X33X_^N\`Y_E
M"A"@X0``C^`K^__K"@"@X8C^_^M____J!8"@X6A`1^((,8?@:``3Y0``4.,O
M```*`;"(X@M1A.`#``#J!`"5Y```4.,I```*`;"+X@80H.$+@*#AROG_ZP`P
M4.+V__\*`##3Y0``4^/S__\**?C_ZP!04.+V_O\:Z/__Z@0CG^4<,)WE`@":
MYP"@H.,`,)/E+".?Y000C>4!$*#C`("-Y0(@C^```)#E>OC_ZUG__^I@_O_K
M#!.?Y:`BG^4".8WB`1"/X/PP@^("()'G`!"2Y0`@D^4!$#+@GP``&@0`H.&!
MW(WB!-"-XO!/O>@)^/_JU%*?Y0T`H.,M^/_K4R"@XP"`H.$%4(_@VO[_ZAPP
MG>4`L)/E;/__ZK`"G^4&$*#A``"/X);Y_^L``%#C``"$!0@```H`,-#E``!3
MXS``4Q,!,*`3`#"@`P$PH!,`,(0%`#"$%77__QH+`*#A`!"@XQ#X_^L`0%#B
M</__"@`PX.,1(.#C`F"@XP101^(`8(WE__?_ZP8@H.,%$*#A!`"@X<7W_^L$
M,%?E``!3XP(``!H#,%?E0P!3XT<```H`,*#C`""@XP`PC>4$`*#A`#"@X^_W
M_^N<!`#K`&"@X0(``.H%$*#A!@"@X:X$`.L"*:#C!1"@X00`H.&O]__K`"!0
MXO;__\K8L9_E!`"@X3"01^)(^/_K15!'X@80H.$+L(_@"4"@X3%@1^)$`$?B
MX`0`ZP$@]>4$`*#A`""-Y0LPH.$!$*#C`"#@X_[W_^L"0(3B!0!6X?7__QJ(
M(9_E`1"@XPB0C>4*`*#A`B"/X`"`C>4$((WE`""@XVPQG^4(($?E:"&?Y0,P
MC^`"((_@#""-Y0`@X./K]__K6?__ZAPPG>4$0)/E``!4XQW__PH$`*#AU??_
MZP,`4.,9__^:,!&?Y00`0.(``(3@`1"/X''W_^L``%#C!+"@`1'__^H",%?E
M00!3X[3__QH!,%?E0P!3X['__QH`,-?E2`!3XZ[__QH!,-?E10!3XZO__QH`
M,.#C!`"@X0!@C>4Y(.#CG/?_ZP40H.$I(*#C!`"@X6+W_^O`,)_EP""?Y0$0
MH.,#,(_@##"-Y;0PG^4"((_@"@"@X00@C>4#,(_@"%"-Y0"`C>4`(.#CM_?_
MZR7__^IP]__K#`$``+1A`0`\8`$`2&`!`.`;``"`'```O!H``)`;```(&@``
M8!L``!P!``!4&P``]%T!``0;``#(&@``2%X!`*P9```H&0``8!H```0;```8
M&```+!L``"P8``!$&@``^!<``'P8``!<6P$`]!<``$@7``#T%@``3!4``%`7
M```4&```!!<``&`7``!L%```@!8``&P"G^5L$I_E``"/X/!`+>ED,I_E#-!-
MXF`BG^4!$)#G`S"/X`U@H.$`$)'E!!"-Y0`0H.,"0)/G``"4Y<7W_^L`4*#A
M``"4Y<+W_^L&$*#A9##5Y64PP.4D`I_E``"/X,KX_^L``%#C`@``"@`PT.4Q
M`%/C8@``"M?[_^L``)3EM/?_Z_P1G^4#,*#C`2"@XP$0C^!/]__K`%!0X@L`
M``H``)3EJ_?_ZPPPE>78(9_E`!"3Y0(@C^`K]__K##"5Y0`PD^4(,)/E`043
MXUD``!H``)3EG_?_Z[`1G^4#,*#C`2"@XP$0C^`Z]__K`%!0X@L```J8`9_E
M!A"@X0``C^"B^/_K`'!0X@``E.5````*D/?_ZPPPE>4'(*#A`!"3Y1'W_^L`
M`)3EBO?_ZP!0H.$``)3EA_?_ZU@1G^4!(*#C`1"/X#CW_^M,(9_E`!"@X04`
MH.$"((_@0%&?Y0+W_^L``)3E>_?_ZP`PH.$%4(_@+`&?Y0`@H.,&$*#A``"/
MX&4@P^6!^/_K`$"@X0``4.,(`(7E$0``"@<=H.,$`*#A,/?_ZP$@@.(`,*#A
M$0!0XP$`4A,F``"*Z""?Y;0PG^4"((_@`S"2YP`@D^4$,)WE`B`SX!T``!H,
MT(WB\("]Z`0`E>5M_?_K`$"@X0``4.,(`(7EY___&JP`G^4``(_@$O?_ZP$P
MT.4``%/CFO__"IC__^I/]__KD#"?Y0P@E>4#,(_@``"2Y00PD^4`$)/E5OG_
MZ[K__^H``)3E1??_ZPPPE>4`$)/E#_?_ZY___^JV]O_K6!"?Y00@H.%4`)_E
M`1"/X```C^`$$)'E`!"1Y?;V_^L@6`$`#`$```A8`0`4`0``_!,``'05``!4
M%0``+!4``!@3``#4%```V!0``#Q8`0",$@``:%8!`#@4``"(5P$`2%<!`/03
M``!H(9_E:#&?Y0(@C^#P0"WI`'!0X@S03>(#,)+G`#"3Y00PC>4`,*#C.0``
M"@`PU^4``%/C-@``"N7X_^L`0*#A`##4Y0``4^,%```*`2"$XB\`4^,"0*`!
M`3#2Y```4^/Z__\:#&&?Y0!05^(!4*`3!F"/X``PEN4!`'/C*0``"@``4^,`
M4*`#`5`%$@``5>,)```:X""?Y=0PG^4"((_@`S"2YP`@D^4$,)WE`B`SX"T`
M`!H,T(WB\("]Z``PU^4``%/C\O__"K`0G^4$(*#C!`"@X0$0C^#@]O_K``!0
MX^O__QJ8()_EA#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@&0``&@<`H.$,T(WB
M\$"]Z";X_^IL`)_E``"/X%'V_^L`0*#AQ?__ZEP`G^4-$*#A``"/X.;W_^L`
M`%#C``"&!=/__PH`,-#E``!3XS``4Q,`,*`#`3"@$P`PA@7,__\*`3"@XP`P
MAN7'___J0/;_ZV15`0`,`0``0%8!`-!4`0"0$0``@%0!`*0/``"($```\$\M
MZ1P@@.+@ZY_EX#N?Y5/?3>(.X(_@!$"-X@00H.%<P(#B`S">YP`PD^5$,8WE
M`#"@XP0PDN0S/[_F`@!<X00P@>3Z__\:#2"@X?Q`A.("$*#A!,"RY00`4N$X
M,)'E)."1Y0P0D>4.,"/@`3`CX`PP(^#C/Z#A0#""Y?/__QH@0)#IF3D'XX(Z
M1>,,0)#E!,"=Y0!@D.4$$"[@$'"0Y0/`C.`%$`'@99&@X0?`C.`$$"'@"""=
MY>;-C.`!P(S@"1`NX`,@@N`&$`'@!"""X`X0(>`"$('@#""=Y6:!H.'L'8'@
M`R""X`Z@@N`(("G@#"`"X&S!H.$)("+@"B""X!"@G>7A+8+@`Z"*X`F@BN`,
MD"C@`9`)X&$1H.$(D"G@"I")X!2@G>7BG8G@`Z"*X`B@BN`!@"S@`H`(X&(A
MH.$,@"C@`K`AX`J`B.`8H)WE";`+X.F-B.`#H(K@#*"*X&G!H.$!D"O@#+`B
MX`J0B>`<H)WE"+`+X.B=B>`#H(K@`:"*X&@1H.$"@"O@`;`LX`J`B.`@H)WE
M";`+X.F-B.`#H(K@`J"*X&DAH.$,D"O@`K`AX`J0B>`DH)WE"+`+X.B=B>`#
MH(K@#*"*X&C!H.$!@"O@#+`BX`J`B.`HH)WE";`+X.F-B.`#H(K@`:"*X&D1
MH.$"D"O@`;`LX`J0B>`LH)WE"+`+X.B=B>`#H(K@`J"*X&@AH.$,@"O@`K`A
MX`J`B.`PH)WE";`+X.F-B.`#H(K@#*"*X&G!H.$!D"O@#+`BX`J0B>`TH)WE
M"+`+X.B=B>`#H(K@`:"*X&@1H.$"@"O@`;`LX`J`B.`XH)WE";`+X.F-B.`#
MH(K@`J"*X&DAH.$,D"O@`K`AX`J0B>`\H)WE"+`+X.B=B>`#H(K@#*"*X&C!
MH.$!@"O@#+`BX`J`B.!`H)WE";`+X.F-B.`#H(K@`:"*X&D1H.$"D"O@`;`L
MX`J0B>!$H)WE"+`+X.B=B>`#H(K@`J"*X&@AH.$,@"O@"H"(X$B@G>7IC8C@
M`Z"*X`S`BN`"H"'@":`*X&F1H.$!H"K@#*"*X$S`G>7HK8K@`\",X`'`C.`)
M$"+@"!`!X&B!H.$"$"'@#!"!X%#`G>7J'8'@`S",X`C`*>`*P`S@`B"#X`G`
M+."A.P[CV3Y&XP+`C.!4()WE:J&@X>'-C.`#((+@"9""X%@@G>4#((+@""""
MX`J`*.`!@"C@"(")X&&1H.%<$)WE[(V(X`,0@>`*$('@":`JX`R@*N!LP:#A
M"J""X&`@G>7HK8K@`R""X`D@@N`,D"G@")`IX&B!H.$)D('@9!"=Y>J=B>`#
M$('@#!"!X`C`+.`*P"S@:J&@X0S`@N!H()WEZ<V,X`,@@N`(((+@"H`HX`F`
M*.!ID:#A"("!X&P0G>7LC8C@`Q"!X`H0@>`)H"K@#*`JX&S!H.$*H(+@<""=
MY>BMBN`#((+@"2""X`R0*>`(D"G@:(&@X0F0@>!T$)WEZIV)X`,0@>`,$('@
M",`LX`K`+.!JH:#A#,""X'@@G>7IS8S@`R""X`@@@N`*@"C@"8`HX&F1H.$(
M@('@?!"=Y>R-B.`#$('@"A"!X`F@*N`,H"K@;,&@X0J@@N"`()WEZ*V*X`,@
M@N`)((+@#)`IX`B0*>!H@:#A"9"!X(00G>7JG8G@:K&@X0,0@>`,$('@",`L
MX`K`+.`,((+@Z:V"X(@@G>4#((+@""""X`N`*.`)P"C@:9&@X0P0@>",P)WE
MZHV!X`D0*^`#P(S@"A`AX`O`C."0L)WE:J&@X0$0@N`#L(O@Z!V!X`FPB^`*
MD"G@""`IX&B!H.$"((S@X9V"X)0@G>4#((+@"B""X`B@*N`!P"K@F*"=Y6$1
MH.$,P(O@`Z"*X.G-C.`(H(K@`8`HX`F`*.!ID:#A"(""X)P@G>7LC8C@I+"=
MY0,@@N`!((+@"1`AX`P0(>!LP:#A`:"*X`P0*>#HK8K@"!`AX`$@@N!H@:#A
MZAV"X*`@G>4#((+@"#`LX`D@@N!JD:#A`Z`JX-P\"^,;/TCC"B""X`.PB^`)
MH(CA#+"+X*C`G>7A+8+@`:`*X`/`C.!A$:#A",",X`F`".`(H(KA`8")X0N@
MBN`"@`C@`;`)X.*MBN`+@(CAL+"=Y0S`B.!B(:#AZHV,X*S`G>4#L(O@`\",
MX`&PB^`)D(S@`L"!X0K`#.`"$`'@`1",X6JAH.$)D('@"A""X>C-B>"TD)WE
M"!`!X&B!H.$#D(G@`I")X`H@`N`"(('A"!"*X0NP@N`,$`'@""`*X.R]B^`"
M$('AN""=Y0D0@>"\D)WE;,&@X0,@@N`*H(+@`Y")X`P@B.$(D(G@"R`"X`R`
M".#K'8'@"(""X6NQH.$*H(C@"R",X6&!H.'AK8K@`2`"X,`0G>4#$('@#!"!
MX`O`#.`,P(+A"""+X0G`C.`*(`+@")`+X.K-C.`)((+AR)"=Y0$0@N#$()WE
M:J&@X0.0B>`#((+@")")X`NP@N`*((CA#"`"X`J`".#L'8'@"(""X6S!H.$+
ML(C@#""*X6&!H.'AO8O@`2`"X,P0G>4#$('@"A"!X`R@"N`*H(+A""",X0F0
MBN`+(`+@"*`,X.N=B>`*((+AU*"=Y0$0@N#0()WE:[&@X0.@BN`#((+@"*"*
MX`S`@N`+((CA"2`"X`N`".#I'8'@"(""X6F1H.$,P(C@"2"+X>&-C.`!(`+@
M8<&@X=@0G>4#$('@"Q"!X`FP"^`+L(+A#"")X0J@B^`((`+@#+`)X.BMBN`+
M((+AX+"=Y0$0@N#<()WE:(&@X0.PB^`#((+@#+"+X`F0@N`(((SA"B`"X`C`
M#.#J'8'@#,""X6JAH.$)D(S@"B"(X6'!H.'AG8G@`2`"X.00G>4#$('@"!"!
MX`J`".`(@(+A#""*X0N`B.`)(`+@#+`*X.F-B.`+((+A[+"=Y0$@@N#H$)WE
M:9&@X0.PB^`#$('@#+"+X`J@@>`)$(SA"!`!X`G`#.#H+8+@#,"!X0J@C.!H
M@:#AXLV*X/"@G>4($(GA`S"*X`(0`>`),(/@8B&@X0B0">`"H(CA"1"!X0R@
M"N`+$('@`K`(X.P=@>`+H(KA;)&@X0,PBN#TP)WEX:V#X-8Q#.-B.DSC`\",
MX&&QH.$(@(S@^,"=Y0/`C.`"P(S@"2`BX`$@(N#\$)WE`H"(X`L@*>#JC8C@
M"B`BX`,0@>!JH:#A"1"!X`J0*^`(D"G@`L",X`F0@>`$$9WE`"&=Y>C-C.`#
M$('@:(&@X0H0@>`#((+@"*`JX`L@@N`,H"K@[)V)X`J@@N`((9WE;,&@X>FM
MBN`#((+@""""X`R`*.`)@"C@:9&@X0B`@>`,$9WEZHV(X`,0@>`,$('@"<`L
MX`K`+.!JH:#A#,""X!`AG>7HS8S@`R""X`D@@N`*D"G@")`IX&B!H.$)D('@
M%!&=Y>R=B>`#$('@"A"!X`B@*N`,H"K@;,&@X0J@@N`8(9WEZ:V*X`,@@N`(
M((+@#(`HX`F`*.!ID:#A"("!X!P1G>7JC8C@`Q"!X`P0@>`)P"S@"L`LX&JA
MH.$,P(+@("&=Y>C-C.`#((+@"2""X`J0*>`(D"G@:(&@X0F0@>`D$9WE[)V)
MX`,0@>`*$('@"*`JX`R@*N!LP:#A"J""X"@AG>7IK8K@`R""X`@@@N`,@"C@
M"8`HX&F1H.$(@('@+!&=Y>J-B.`#$('@#!"!X`G`+.`*P"S@:J&@X0S`@N`P
M(9WEZ,V,X`,@@N`)((+@"I`IX`B0*>!H@:#A"1"!X#21G>7L'8'@`Y")X`J0
MB>`(H"K@#*`JX&S!H.$*((+@.*&=Y>$M@N`#H(K@"*"*X`R`*.`!@"C@81&@
MX0B0B>`\@9WEXIV)X`.`B.`,@(C@`<`LX`+`+.!B(:#A#,"*X`)PA^#IS8S@
M$'"`Y6SACN`(X(#E0.&=Y0,PCN`&,(/@`3"#X`(0(>`)$"'@:9&@X0$0B.`)
M("+@[!V!X`P@(N`",(/@1""?Y0%0A>#A'8/@-#"?Y0(@C^`$4(#E"4"$X``0
M@.4,0(#E`S"2YP`@D^5$,9WE`B`SX`$``!I3WXWB\(^]Z#SS_^O(4P$`#`$`
M`"!(`0`00"WI8`"@XUKS_^L`(*#C`<,"XT7'1N.)&PKCS1].XP#`@.4$$(#E
M_LP-X[K(2>-V%`7C,A!!XPC`@.4,$(#E\!$.X](33.,4((#E$!"`Y1@@@.5<
M((#E$("]Z/!'+>D"D*#A@B&@X10PD.4`4*#A`4"@X1R`A>(",)/@&""0Y10P
M@.5<`)#E`2""(JDN@N`8((7E``!0XR```!H_`%GC+@``VD"02>(I8Z#A`7"&
MX@=SA.`$$*#A"#"@X4!`A.(`X)'E$!"!X@S`$>40,(/B"``1Y00@$>4$`%'A
M$.`#Y0S``^4(``/E!"`#Y?/__QH!0*#A!0"@X<'\_^L'`%3AZ___&@:32>`)
M(*#A!Q"@X0@`H.'A\O_K7)"%Y?"'O>A`8&#B``"(X`8`6>$)8*"Q!B"@X=GR
M_^M<,)7E`S"&X%PPA>5``%/C\(>]&`4`H.$&D$G@!D"$X*G\_^O.___J!'"@
MX>?__^KP02WI''"!X@%`H.$4,)'E`%"@X1A@D>5_$.#C,X^_YM,QY><V;[_F
M`2"#XC@`4N,"`(?@`Q#'YSP``-I`(&+B`!"@XQ[S_^L$`*#ADOS_ZP<`H.$X
M(*#C`!"@XQCS_^L$`*#A5&"$Y5B`A.6*_/_K`S#4Y0`PQ>4$`*#ALC#4X0$P
MQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0<PU.4$,,7EMC#4X04PQ>4$,)3E(S2@
MX08PQ>4$,)3E!S#%Y0LPU.4(,,7ENC#4X0DPQ>4(,)3E(S2@X0HPQ>4(,)3E
M"S#%Y0\PU.4,,,7EOC#4X0TPQ>4,,)3E(S2@X0XPQ>4,,)3E#S#%Y1,PU.40
M,,7ELC'4X1$PQ>40,)3E(S2@X1(PQ>40,)3E$S#%Y?!!O>A^\O_J."!BX@`0
MH./A\O_KQ___ZO!'+>D`<*#A3&"?Y4Q0G^4!@*#A!F"/X`*0H.$%4(_@5/+_
MZP5@1N!&8;#A\(>]"`101>(`0*#C!#"UY0D@H.$($*#A!P"@X0%`A.(S_R_A
M!`!6X??__QKPA[WH"$0!`/Q#`0`>_R_A"#"?Y0,PC^``,)/E=/+_Z@Q&`0`(
M0"WI"("]Z`$``@`O=&UP`````"X```!005)?5$U01$E2``!414U01$E2`%1-
M4`!54T52`````%5315).04U%`````"5S+R5S````+P```"]P<F]C+W-E;&8O
M97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI0
M05(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`%!!4E]414U0`````%!!4E]0
M4D]'3D%-10`````Z````)7,E<R5S``!015),-4Q)0@````!015),3$E"`%!%
M4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"
M04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````3$1?3$E"
M4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE
M<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````
M<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-30```!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`````"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*)%!!4E]-04=)0R`](")<
M;E!!4BYP;5QN(CL*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D
M("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H
M*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*
M;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?
M=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["DU!1TE#.B![
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@
M7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D
M(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R
M92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1C
M:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US
M(%]&2#L*;7D@)&UA9VEC7W!O<R`]("1S:7IE("T@)'-I>F4@)2`D8VAU;FM?
M<VEZ93L@(R!.3U1%.B`D;6%G:6-?<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H
M=6YK7W-I>F4*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@
M)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@
M;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L
M("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0[
M"GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0II9B`H)&UA9VEC7W!O
M<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!
M4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B
M=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES
M=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;
M56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B
M87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@
M)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N
M;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@
M8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP
M<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D
M9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I
M;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U
M;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*=6YL97-S("@D8G5F(&5Q(")02UPP,#-<,#`T(BD@>PIO
M=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O
M<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY
M("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV
M92`B)'!A<B)=.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@
M)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE
M72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N
M)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS
M965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?
M<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92![
M"FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\
M(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$
M>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@
M(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA
M;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]
M"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@
M;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H
M+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@
M:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q
M6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@
M/2!U;F1E9CL*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*
M8VQO<V4@)&9H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N
M=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T
M96X@87,@(B1N86UE(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q
M*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4@)&9H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S
M=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L
M90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O
M<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N
M86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T
M<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D<WES>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@
M)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X
M(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D<WES>U]D96QI
M;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]=&5M
M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@
M7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\[
M"FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE
M("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*
M;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D:64@<7%;0V%N
M)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P
M<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY
M("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S
M>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D
M<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<
M12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```'!E<FQX<VDN8P``
M`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````."._W\!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````@&@``N!D```$`
M```H`P```0```#,#```!````0P,```$```!-`P``#P```-4$```,````_!(`
M``T`````2@``&0```*2-`0`;````!````!H```"HC0$`'`````0```#U_O]O
MM`$```4````$"@``!@```%0#```*````^`0```L````0````%0`````````#
M````Q(X!``(```#H`0``%````!$````7````%!$``!$````T$```$@```.``
M```3````"````!@`````````^___;P$```C^__]OU`\``/___V\#````\/__
M;_P.``#Z__]O$```````````````````````````````````````````````
M``````````"LC0$````````````($P``"!,```@3```($P``"!,```@3```(
M$P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3
M```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,`
M``@3```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``
M"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```(
M$P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``Z$D`````
M````````````````````````````````````````A$D```````#X%0``````
M``````````````````20`0#_____#$H``!1*````````&$H``!Q*```D2@``
MJ$H``"Q*````````,$H``#A*````````0$T``$=#0SH@*$=.52D@,3`N,BXP
M`$=#0SH@*&-R;W-S=&]O;"U.1R`Q+C(S+C`N-#$X+60U.3`I(#$P+C(N,`!!
M,@```&%E86)I``$H````!3<M00`&"@=!"`$)`@H$$@03`10!%0$7`Q@!&0$:
M`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN
M;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E
M<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````
M```````````````````````````````+`````0````(```!4`0``5`$``!D`
M``````````````$`````````$P````<````"````<`$``'`!```D````````
M```````$`````````"8````'`````@```)0!``"4`0``(```````````````
M!``````````T````]O__;P(```"T`0``M`$``*`!```%``````````0````$
M````/@````L````"````5`,``%0#``"P!@``!@````,````$````$````$8`
M```#`````@````0*```$"@``^`0``````````````0````````!.````____
M;P(```#\#@``_`X``-8````%``````````(````"````6P```/[__V\"````
MU`\``-0/``!@````!@````,````$`````````&H````)`````@```#00```T
M$```X`````4`````````!`````@```!S````"0```$(````4$0``%!$``.@!
M```%````%0````0````(````?`````$````&````_!(``/P2```,````````
M```````$`````````'<````!````!@````@3```($P``\`(`````````````
M!`````0```""`````0````8```#X%0``^!4```@T``````````````0`````
M````B`````$````&`````$H```!*```(```````````````$`````````(X`
M```!`````@````A*```(2@``OC\`````````````!`````````"6`````0``
M<((```#(B0``R(D```@````-``````````0`````````H0````$````"````
MT(D``-")```$```````````````$`````````*L````.`````P```*2-`0"D
MC0``!```````````````!`````0```"W````#P````,```"HC0$`J(T```0`
M``````````````0````$````PP````8````#````K(T!`*R-```8`0``!@``
M```````$````"````,P````!`````P```,2.`0#$C@``/`$`````````````
M!`````0```#1`````0````,`````D`$``)```$````````````````0`````
M````UP````@````#````0)`!`$"0```4$``````````````$`````````-P`
M```!````,`````````!`D```/0```````````````0````$```#E`````P``
M<```````````?9```#,```````````````$``````````0````,`````````
<`````+"0``#U```````````````!````````````
